@@ -5,7 +5,7 @@ import logging
 import math
 from datetime import datetime
 from .parameter import Parameter
-from .tools import handle_date, handle_db_to_list, handle_db_dict
+from .tools import handle_date, handle_db_to_list, handle_db_dict, handle_db_id
 from flask import abort, Response
 from bson import ObjectId
 
@@ -50,6 +50,7 @@ class DBConnect():
 
     def update_docu(self, find_docu: dict, modify_docu: dict, many=False) -> dict:
         try:
+            find_docu = handle_db_id(find_docu)
             if many:
                 student = self.mongo_collection.update_many(
                     find_docu, modify_docu)
@@ -65,6 +66,7 @@ class DBConnect():
 
     def find_docu(self, find_dict: dict, many: bool = True) -> list:
         try:
+            find_dict = handle_db_id(find_dict)
             if many:
                 # 多文档查询方式
                 query_cursor = self.mongo_collection.find(find_dict)
@@ -72,6 +74,8 @@ class DBConnect():
             else:
                 # 单文档查询方式
                 query_dict = self.mongo_collection.find_one(find_dict)
+                if not query_dict:
+                    return []
                 return [handle_db_dict(query_dict)]
         except Exception as err:
             str_data = 'MongoDB(组件)出现查询错误: {0}'.format(err)
