@@ -46,7 +46,8 @@ def handle_db_to_list(db_cursor: Cursor) -> list:
 
 def handle_db_dict(db_dict: dict) -> dict:
     try:
-        db_dict['_id'] = str(db_dict['_id'])
+        db_dict['id'] = str(db_dict['_id'])
+        del db_dict['_id']
         db_dict['creation_time'] = int(time.mktime(
             db_dict['creation_time'].timetuple())) * 1000
         return db_dict
@@ -60,6 +61,9 @@ def handle_db_id(data_dict: dict) -> dict:
     try:
         if data_dict.__contains__('_id'):
             data_dict['_id'] = ObjectId(str(data_dict['_id']))
+        elif data_dict.__contains__('id'):
+            data_dict['_id'] = ObjectId(str(data_dict['id']))
+            del data_dict['id']
         return data_dict
     except Exception as err:
         str_data = 'MongoDB _id 格式解析异常: {0}'.format(err)
